@@ -1,4 +1,4 @@
-from scrapy.core.exceptions import DropItem
+from scrapy.exceptions import DropItem
 
 class FilterWordsPipeline(object):
     """A pipeline for filtering out items which contain certain words in their
@@ -7,7 +7,7 @@ class FilterWordsPipeline(object):
     # put all words in lowercase
     words_to_filter = ['politics', 'religion']
 
-    def process_item(self, domain, item):
+    def process_item(self, item, spider):
         for word in self.words_to_filter:
             if word in unicode(item['description']).lower():
                 raise DropItem("Contains forbidden word: %s" % word)
