@@ -2,17 +2,20 @@
 Scrapy - a screen scraping framework written in Python
 """
 
-version_info = (0, 8, 0, '', 0)
-__version__ = "0.8"
+version_info = (0, 12, 0)
+__version__ = "0.12.0"
 
-import sys, os
+import sys, os, warnings
 
 if sys.version_info < (2,5):
     print "Scrapy %s requires Python 2.5 or above" % __version__
     sys.exit(1)
 
+# ignore noisy twisted deprecation warnings
+warnings.filterwarnings('ignore', category=DeprecationWarning, module='twisted')
+
 # monkey patches to fix external library issues
-from scrapy.xlib import twisted_250_monkeypatches
+from scrapy.xlib import twisted_250_monkeypatches, urlparse_monkeypatches
 
 # optional_features is a set containing Scrapy optional features
 optional_features = set()
@@ -23,3 +26,12 @@ except ImportError:
     pass
 else:
     optional_features.add('ssl')
+
+try:
+    import boto
+except ImportError:
+    pass
+else:
+    optional_features.add('boto')
+
+__version__ = '.'.join(map(str, version_info)) + '.2528'
\ No newline at end of file
